@@ -125,7 +125,6 @@ public final class ModuleLoaderMap {
             "java.rmi",
             "java.security.sasl",
             "java.xml",
-            "jdk.incubator.foreign",
             "jdk.incubator.vector",
             "jdk.internal.vm.ci",
             "jdk.jfr",
@@ -151,15 +150,13 @@ public final class ModuleLoaderMap {
             "java.transaction.xa",
             "java.xml.crypto",
             "jdk.accessibility",
-            "jdk.aot",
             "jdk.charsets",
             "jdk.crypto.cryptoki",
-            "jdk.crypto.ec",
             "jdk.crypto.mscapi",
             "jdk.dynalink",
+            "jdk.graal.compiler",
+            "jdk.graal.compiler.management",
             "jdk.httpserver",
-            "jdk.internal.vm.compiler",
-            "jdk.internal.vm.compiler.management",
             "jdk.jsobject",
             "jdk.localedata",
             "jdk.naming.dns",
